"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchStats = void 0;
var https_1 = require("https");
var parseBody = function (body) {
    var streak = {
        best: 0,
        current: 0,
    };
    var contributions = {
        best: 0,
        total: 0,
        current: 0,
    };
    var contributionMatches = [];
    var contributionRegex = /(\d+|No) contributions on/g;
    var contributionMatch;
    while ((contributionMatch = contributionRegex.exec(body)))
        contributionMatches.push(contributionMatch);
    contributionMatches.forEach(function (contributionMatch) {
        var contributionCount = contributionMatch[1] === 'No' ? 0 : parseInt(contributionMatch[1], 10);
        contributions.total += contributionCount;
        contributions.current = contributionCount;
        if (contributionCount > contributions.best)
            contributions.best = contributionCount;
        streak.current = contributionCount > 0 ? (streak.current += 1) : 0;
        if (streak.current > streak.best)
            streak.best = streak.current;
    });
    return { streak: streak, contributions: contributions };
};
var fetchStats = function (username, options) {
    if (options === void 0) { options = {}; }
    return new Promise(function (resolve, reject) {
        (0, https_1.get)("https://github.com/users/".concat(username, "/contributions"), function (response) {
            var body = '';
            response.setEncoding('utf8');
            response.on('data', function (chunk) { return (body += chunk); });
            response.on('end', function () {
                if (response.statusCode === 404) {
                    if (options.onFailure)
                        return options.onFailure(response);
                    return reject(response);
                }
                var data = parseBody(body);
                if (options.onSuccess)
                    return options.onSuccess(data);
                return resolve(data);
            });
        });
    });
};
exports.fetchStats = fetchStats;
